#ifndef NT2_INCLUDE_FUNCTIONS_NEXT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NEXT_HPP_INCLUDED

#include <nt2/ieee/include/functions/next.hpp>

#endif
